@@ -21,8 +21,8 @@ def ScrollBar(root, widget, side="right", fill="y"):
     scrollbar.pack(side=side, fill=fill)
     a.config(yscrollcommand=scrollbar.set)
 
-def Label(parent, textvariabl, text="Default Text", font="Helvetica", size=12, color="black", wraplenght=2):
-    label = ttk.Label(parent, text=text,  font = (font, size), foreground = color, wraplength=wraplenght, textvariable=textvariabl)
+def Label(parent, textvariabl, text=None, font="Helvetica", size=12, color="black", wraplenght=2, width=50, height=50):
+    label = ttk.Label(parent, text=text,  font = (font, size), foreground = color, wraplength=wraplenght, textvariable=textvariabl, width=width, height=height)
     return label
 
     
@@ -36,7 +36,6 @@ def Font(name = 'arial', size = 20, weight = "bold"):
 def StrVar(master, string):
     v = tk.StringVar(master, string)
     return v
-
 def OpenFile(title):
     file_path = filedialog.askopenfilename(title="Select a file")
     return file_path
